# has_birth_event

None

URI: https://w3id.org/linkml/tests/kitchen_sink/has_birth_event



<!-- no inheritance hierarchy -->


## Properties

 * Range: BirthEvent

## Identifier and Mapping Information


